@@ -6,7 +6,7 @@
 ;; Maintainer: notmuch-indicator Development <~protesilaos/notmuch-indicator@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/notmuch-indicator
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/notmuch-indicator
-;; Version: 1.0.0
+;; Version: 1.0.1
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mail
 
@@ -183,7 +183,7 @@ option `notmuch-indicator-refresh-count'."
                  (propertize label 'face face)
                (or label ""))
              count)
-     'mouse-face 'highlight
+     'mouse-face 'mode-line-highlight
      'help-echo (format "mouse-1: Open notmuch search for `%s'" terms)
      'local-map map)))
 
